==> 1.1.6-to-1.1.7.zip: public/assets/js/custom/function.js <==
// function isRTL() {
//     var dir = $('html').attr('dir');
//     if (dir === 'rtl') {
//         return true;
//     } else {
//         return false;
//     }
// }

// let toast_position = 'top-right';
// if (isRTL()) {
//     toast_position = 'top-left';
// } else {
//     toast_position = 'top-right';
// }

function showErrorToast(message) {
    Toastify({
        text: message,
        duration: 3000,
        close: !0,
        backgroundColor: '#dc3545',
        // position: toast_position
    }).showToast();
}

function showSuccessToast(message) {
    Toastify({
        text: message,
        duration: 3000,
        close: !0,
        backgroundColor: "linear-gradient(to right, #00b09b, #96c93d)",
        // position: toast_position
    }).showToast();
}

function showWarningToast(message) {
    Toastify({
        text: message,
        duration: 3000,
        close: !0,
        backgroundColor: "yellow",
        // position: toast_position
    }).showToast();
}


/**
 *
 * @param type
 * @param url
 * @param data
 * @param {function} beforeSendCallback
 * @param {function} successCallback - This function will be executed if no Error will occur
 * @param {function} errorCallback - This function will be executed if some error will occur
 * @param {function} finalCallback - This function will be executed after all the functions are executed
 * @param processData
 */
function ajaxRequest(type, url, data, beforeSendCallback = null, successCallback = null, errorCallback = null, finalCallback = null, processData = false) {
    $.ajax({
        type: type,
        url: url,
        data: data,
        cache: false,
        processData: processData,
        contentType: false,
        dataType: 'json',
        beforeSend: function () {
            if (beforeSendCallback != null) {
                beforeSendCallback();
            }
        },
        success: function (data) {
            if (!data.error) {
                if (successCallback != null) {
                    successCallback(data);
                }
            } else {
                if (errorCallback != null) {
                    errorCallback(data);
                }
            }

            if (finalCallback != null) {
                finalCallback(data);
            }
        }, error: function (jqXHR) {
            console.log(jqXHR);
            if (jqXHR.responseJSON) {
                showErrorToast(jqXHR.responseJSON.message);
            }
            if (finalCallback != null) {
                finalCallback();
            }
        }
    })
}

function formAjaxRequest(type, url, data, formElement, submitButtonElement, successCallback = null, errorCallback = null) {
    let submitButtonText = submitButtonElement.val();

    function beforeSendCallback() {
        submitButtonElement.val('Please Wait...').attr('disabled', true);
    }

    function mainSuccessCallback(response) {
        if (response.warning) {
            showWarningToast(response.message);
        } else {
            showSuccessToast(response.message);
        }

        if (successCallback != null) {
            successCallback(response);
        }
    }

    function mainErrorCallback(response) {
        showErrorToast(response.message);
        if (errorCallback != null) {
            errorCallback(response);
        }
    }

    function finalCallback() {
        submitButtonElement.val(submitButtonText).attr('disabled', false);
    }

    ajaxRequest(type, url, data, beforeSendCallback, mainSuccessCallback, mainErrorCallback, finalCallback)
}

/**
 * @param {string} [url] - Ajax URL that will be called when the Confirm button will be clicked
 * @param {string} [method] - GET / POST / PUT / PATCH / DELETE
 * @param {Object} [options] - Options to Configure SweetAlert
 * @param {string} [options.title] - Are you sure
 * @param {string} [options.text] - You won't be able to revert this
 * @param {string} [options.icon] - 'warning'
 * @param {boolean} [options.showCancelButton] - true
 * @param {string} [options.confirmButtonColor] - '#3085d6'
 * @param {string} [options.cancelButtonColor] - '#d33'
 * @param {string} [options.confirmButtonText] - Confirm
 * @param {string} [options.cancelButtonText] - Cancel
 * @param {function} [options.successCallBack] - function()
 * @param {function} [options.errorCallBack] - function()
 */
function showSweetAlertConfirmPopup(url, method, options = {}) {
    let opt = options;
    if(!options){
        opt = {
            title: window.trans["Are you sure"],
            text: window.trans["You wont be able to revert this"],
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#3085d6',
            cancelButtonColor: '#d33',
            confirmButtonText: window.trans["Confirm"],
            cancelButtonText: window.trans["Cancel"],
            successCallBack: function () {
            },
            errorCallBack: function (response) {
            },
            ...options,
        }
    }

    Swal.fire({
        title: opt.title,
        text: opt.text,
        icon: opt.icon,
        showCancelButton: opt.showCancelButton,
        confirmButtonColor: opt.showCancelButton,
        cancelButtonColor: opt.cancelButtonColor,
        confirmButtonText: opt.confirmButtonText,
        cancelButtonText: opt.cancelButtonText
    }).then((result) => {
        if (result.isConfirmed) {
            function successCallback(response) {
                showSuccessToast(response.message);
                opt.successCallBack(response);
            }

            function errorCallback(response) {
                showErrorToast(response.message);
                opt.errorCallBack(response);
            }

            ajaxRequest(method, url, null, null, successCallback, errorCallback);
        }
    })
}


/**
 *
 * @param {string} [url] - Ajax URL that will be called when the Delete will be successfully
 * @param {Object} [options] - Options to Configure SweetAlert
 * @param {string} [options.text] - "Are you sure?"
 * @param {string} [options.title] - "You won't be able to revert this!"
 * @param {string} [options.icon] - "warning"
 * @param {boolean} [options.showCancelButton] - true
 * @param {string} [options.confirmButtonColor] - "#3085d6"
 * @param {string} [options.cancelButtonColor] - "#d33"
 * @param {string} [options.confirmButtonText] - "Yes, delete it!"
 * @param {string} [options.cancelButtonText] - "Cancel"
 * @param {function} [options.successCallBack] - function()
 * @param {function} [options.errorCallBack] - function()
 */
function showDeletePopupModal(url, options = {}) {

    // To Preserve OLD
    let opt = {
        title: window.trans["Are you sure"],
        text: window.trans["You wont be able to revert this"],
        icon: 'error',
        showCancelButton: true,
        confirmButtonColor: '#3085d6',
        cancelButtonColor: '#d33',
        confirmButtonText: window.trans["Yes Delete"],
        cancelButtonText: window.trans['Cancel'],
        successCallBack: function () {
        },
        errorCallBack: function (response) {
        },
        ...options,
    }
    showSweetAlertConfirmPopup(url, 'DELETE', opt);
}

==> 1.1.8-to-1.1.9.zip: public/assets/js/custom/function.js <==
// function isRTL() {
//     var dir = $('html').attr('dir');
//     if (dir === 'rtl') {
//         return true;
//     } else {
//         return false;
//     }
// }

// let toast_position = 'top-right';
// if (isRTL()) {
//     toast_position = 'top-left';
// } else {
//     toast_position = 'top-right';
// }

function showErrorToast(message) {
    Toastify({
        text: message,
        duration: 3000,
        close: !0,
        backgroundColor: '#dc3545',
        // position: toast_position
    }).showToast();
}

function showSuccessToast(message) {
    Toastify({
        text: message,
        duration: 3000,
        close: !0,
        backgroundColor: "linear-gradient(to right, #00b09b, #96c93d)",
        // position: toast_position
    }).showToast();
}

function showWarningToast(message) {
    Toastify({
        text: message,
        duration: 3000,
        close: !0,
        backgroundColor: "yellow",
        // position: toast_position
    }).showToast();
}


/**
 *
 * @param type
 * @param url
 * @param data
 * @param {function} beforeSendCallback
 * @param {function} successCallback - This function will be executed if no Error will occur
 * @param {function} errorCallback - This function will be executed if some error will occur
 * @param {function} finalCallback - This function will be executed after all the functions are executed
 * @param processData
 */
function ajaxRequest(type, url, data, beforeSendCallback = null, successCallback = null, errorCallback = null, finalCallback = null, processData = false) {
    $.ajax({
        type: type,
        url: url,
        data: data,
        cache: false,
        processData: processData,
        contentType: false,
        dataType: 'json',
        beforeSend: function () {
            if (beforeSendCallback != null) {
                beforeSendCallback();
            }
        },
        success: function (data) {
            if (!data.error) {
                if (successCallback != null) {
                    successCallback(data);
                }
            } else {
                if (errorCallback != null) {
                    errorCallback(data);
                }
            }

            if (finalCallback != null) {
                finalCallback(data);
            }
        }, error: function (jqXHR) {
            console.log(jqXHR);
            if (jqXHR.responseJSON) {
                showErrorToast(jqXHR.responseJSON.message);
            }
            if (finalCallback != null) {
                finalCallback();
            }
        }
    })
}

function formAjaxRequest(type, url, data, formElement, submitButtonElement, successCallback = null, errorCallback = null) {
    let submitButtonText = submitButtonElement.val();

    function beforeSendCallback() {
        submitButtonElement.val('Please Wait...').attr('disabled', true);
    }

    function mainSuccessCallback(response) {
        if (response.warning) {
            showWarningToast(response.message);
        } else {
            showSuccessToast(response.message);
        }

        if (successCallback != null) {
            successCallback(response);
        }
    }

    function mainErrorCallback(response) {
        showErrorToast(response.message);
        if (errorCallback != null) {
            errorCallback(response);
        }
    }

    function finalCallback() {
        submitButtonElement.val(submitButtonText).attr('disabled', false);
    }

    ajaxRequest(type, url, data, beforeSendCallback, mainSuccessCallback, mainErrorCallback, finalCallback)
}

/**
 * @param {string} [url] - Ajax URL that will be called when the Confirm button will be clicked
 * @param {string} [method] - GET / POST / PUT / PATCH / DELETE
 * @param {Object} [options] - Options to Configure SweetAlert
 * @param {string} [options.title] - Are you sure
 * @param {string} [options.text] - You won't be able to revert this
 * @param {string} [options.icon] - 'warning'
 * @param {boolean} [options.showCancelButton] - true
 * @param {string} [options.confirmButtonColor] - '#3085d6'
 * @param {string} [options.cancelButtonColor] - '#d33'
 * @param {string} [options.confirmButtonText] - Confirm
 * @param {string} [options.cancelButtonText] - Cancel
 * @param {function} [options.successCallBack] - function()
 * @param {function} [options.errorCallBack] - function()
 */
function showSweetAlertConfirmPopup(url, method, options = {}) {
    let opt = options;
    if(!options){
        opt = {
            title: window.trans["Are you sure"],
            text: window.trans["You wont be able to revert this"],
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#198754',
            cancelButtonColor: '#d33',
            confirmButtonText: window.trans["Confirm"],
            cancelButtonText: window.trans["Cancel"],
            reverseButtons: true,
            successCallBack: function () {
            },
            errorCallBack: function (response) {
            },
            ...options,
        }
    }
    console.log(opt);


    Swal.fire({
        title: opt.title,
        text: opt.text,
        icon: opt.icon,
        showCancelButton: opt.showCancelButton,
        confirmButtonColor: opt.confirmButtonColor,
        cancelButtonColor: opt.cancelButtonColor,
        confirmButtonText: opt.confirmButtonText,
        cancelButtonText: opt.cancelButtonText,
        reverseButtons: opt.reverseButtons ?? false
    }).then((result) => {
        if (result.isConfirmed) {
            function successCallback(response) {
                showSuccessToast(response.message);
                opt.successCallBack(response);
            }

            function errorCallback(response) {
                showErrorToast(response.message);
                opt.errorCallBack(response);
            }

            ajaxRequest(method, url, null, null, successCallback, errorCallback);
        }
    })
}


/**
 *
 * @param {string} [url] - Ajax URL that will be called when the Delete will be successfully
 * @param {Object} [options] - Options to Configure SweetAlert
 * @param {string} [options.text] - "Are you sure?"
 * @param {string} [options.title] - "You won't be able to revert this!"
 * @param {string} [options.icon] - "warning"
 * @param {boolean} [options.showCancelButton] - true
 * @param {string} [options.confirmButtonColor] - "#3085d6"
 * @param {string} [options.cancelButtonColor] - "#d33"
 * @param {string} [options.confirmButtonText] - "Yes, delete it!"
 * @param {string} [options.cancelButtonText] - "Cancel"
 * @param {function} [options.successCallBack] - function()
 * @param {function} [options.errorCallBack] - function()
 */
function showDeletePopupModal(url, options = {}) {

    // To Preserve OLD
    let opt = {
        title: window.trans["Are you sure"],
        text: window.trans["You wont be able to revert this"],
        icon: 'error',
        showCancelButton: true,
        confirmButtonColor: '#198754',
        cancelButtonColor: '#d33',
        confirmButtonText: window.trans["Yes Delete"],
        cancelButtonText: window.trans['Cancel'],
        reverseButtons: true,
        successCallBack: function () {
        },
        errorCallBack: function (response) {
        },
        ...options,
    }
    showSweetAlertConfirmPopup(url, 'DELETE', opt);
}
// Function to make remove button accessible on the basis of Option Section Length
let toggleAccessOfDeleteButtons = () => {
    if ($('.option-section').length >= 3) {
        $('.remove-default-option').removeAttr('disabled');
    } else {
        $('.remove-default-option').attr('disabled', true);
    }
}
